==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mi/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Whakaaetia te Puku Whakamuri Taonga',
  'bulk_delete_help'	=> 'Arotakehia nga rawa mo te whakakore nui i raro. Kia mukua, ka taea te whakahoki mai i enei taonga, engari kaore i te hono atu ki nga kaiwhakamahi e tukuna ana ki a raatau.',
  'bulk_delete_warn'	=> 'Kei te tata koe ki te muku: te hua moni rawa.',
	'bulk_update'		=> 'Kaupapa Whakatairanga Nui',
	'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga hua maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
	'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: rawa hua.',
    'checkedout_to'		=> 'Kua aroahia ki te',
    'checkout_date'		=> 'Rā Rārangi',
    'checkin_date'		=> 'Rangi Titiro',
    'checkout_to'		=> 'Whakaritea ki',
    'cost'				=> 'Utu Hokona',
    'create'			=> 'Waihanga Ahua',
    'date'				=> 'Raa Hokona',
    'depreciation'	    => 'Te whakahekenga moni',
    'depreciates_on'	=> 'Whakapaihia ana i runga',
    'default_location'	=> 'Tauwāhi Taunoa',
    'eol_date'			=> 'EOL Rā',
    'eol_rate'			=> 'EOL Tau',
    'expected_checkin'  => 'Ko te Whakataunga Whakataunga Whakaaro',
    'expires'			=> 'Ka puta',
    'fully_depreciated'	=> 'Kua tino tohaina',
    'help_checkout'		=> 'Ki te hiahia koe ki te tautapa i tenei taonga tonu, tīpakohia "Ka rite ki te Whakamahia" mai i te rārangi mana i runga.',
    'mac_address'		=> 'Wāhitau MAC',
    'manufacturer'		=> 'Kaihanga',
    'model'				=> 'Tauira',
    'months'			=> 'marama',
    'name'				=> 'Ingoa Ahua',
    'notes'				=> 'Tuhipoka',
    'order'				=> 'Tau Tau',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Ka taea e nga kaiwhakamahi te tono mo tenei taonga',
    'select_statustype'	=> 'Tīpakohia te Momo Tūnga',
    'serial'			=> 'Waea',
    'status'			=> 'Tūnga',
    'tag'				=> 'Tae Taonga',
    'update'			=> 'Te Whakahou Ahua',
    'warranty'			=> 'Te tiwhikete',
		'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'tau',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mi/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Whakaaetia te Puku Whakamuri Taonga',
  'bulk_delete_help'	=> 'Arotakehia nga rawa mo te whakakore nui i raro. Kia mukua, ka taea te whakahoki mai i enei taonga, engari kaore i te hono atu ki nga kaiwhakamahi e tukuna ana ki a raatau.',
  'bulk_delete_warn'	=> 'Kei te tata koe ki te muku: te hua moni rawa.',
    'bulk_update'		=> 'Kaupapa Whakatairanga Nui',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga hua maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'bulk_update_warn'	=> 'Kei te tata koe ki te whakatika i nga taonga o: rawa hua.',
    'checkedout_to'		=> 'Kua aroahia ki te',
    'checkout_date'		=> 'Rā Rārangi',
    'checkin_date'		=> 'Rangi Titiro',
    'checkout_to'		=> 'Whakaritea ki',
    'cost'				=> 'Utu Hokona',
    'create'			=> 'Waihanga Ahua',
    'date'				=> 'Raa Hokona',
    'depreciation'	    => 'Te whakahekenga moni',
    'depreciates_on'	=> 'Whakapaihia ana i runga',
    'default_location'	=> 'Tauwāhi Taunoa',
    'eol_date'			=> 'EOL Rā',
    'eol_rate'			=> 'EOL Tau',
    'expected_checkin'  => 'Ko te Whakataunga Whakataunga Whakaaro',
    'expires'			=> 'Ka puta',
    'fully_depreciated'	=> 'Kua tino tohaina',
    'help_checkout'		=> 'Ki te hiahia koe ki te tautapa i tenei taonga tonu, tīpakohia "Ka rite ki te Whakamahia" mai i te rārangi mana i runga.',
    'mac_address'		=> 'Wāhitau MAC',
    'manufacturer'		=> 'Kaihanga',
    'model'				=> 'Tauira',
    'months'			=> 'marama',
    'name'				=> 'Ingoa Ahua',
    'notes'				=> 'Tuhipoka',
    'order'				=> 'Tau Tau',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Ka taea e nga kaiwhakamahi te tono mo tenei taonga',
    'select_statustype'	=> 'Tīpakohia te Momo Tūnga',
    'serial'			=> 'Waea',
    'status'			=> 'Tūnga',
    'tag'				=> 'Tae Taonga',
    'update'			=> 'Te Whakahou Ahua',
    'warranty'			=> 'Te tiwhikete',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'tau',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
